@@ -1,5 +1,5 @@
 import random
-import socket
+import socket,os
 from aishu import setting
 
 
@@ -28,14 +28,13 @@ class date(object):
         return ip
 
     def getlocalhostIp(self):
-        try:
-            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-            s.connect(('8.8.8.8', 80))
-            ip = s.getsockname()[0]
-        finally:
-            s.close()
+        env_dict = os.environ
+        if 'hostIP' in env_dict:
+            hostIP = env_dict['hostIP']
+        else:
+            hostIP=self.get_host_ip()
+        return hostIP
 
-        return ip
     def getIpVR(self):
         return '{ip1}.{ip2}.{ip3}.{ip4}'.format(ip1=10, ip2=random.choice(range(10, 250)),
                                                 ip3=random.choice(range(10, 250)), ip4=random.choice(range(10, 250)))
@@ -59,3 +58,6 @@ class date(object):
         # 获取计算机名称
         hostname = socket.gethostname()
         return hostname
+
+if __name__ == '__main__':
+    print(date().getlocalhostIp())
\ No newline at end of file
